| f1 | R Documentation |
The first integrate function
f1(t, survdist, k, lambda0)
t |
time variable |
survdist |
survival distribution of uncured patients. It can be " |
k |
if |
lambda0 |
the scale parameter of exponential distribution or Weibull distribution for survival times of uncured patients in the control arm. The density function of Weibull distribution with shape parameter
for
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.